Learn R Programming

MLCIRTwithin (version 1.1)

lk_obs_score_between: Compute observed log-likelihood and score

Description

Function used within est_multi_poly_between to compute observed log-likelihood and score.

Usage

lk_obs_score_between(par_comp, lde, lpar, lga, S, R, yv, k, rm, lv, J, fv, link, disc, indga, glob, refitem, miss, ltype, XXdis, Xlabel, ZZ0,fort)

Arguments

par_comp
complete vector of parameters
lde
length of de
lpar
length of par
lga
length of ga
S
matrix of responses
R
matrix of observed responses indicator
yv
vector of frequencies
k
number of latent classes for the latent variable
rm
number of dimensions for the latent variable
lv
number of response categories for each item
J
number of items
fv
indicator of constrained parameters
link
link function
disc
presence of discrimination parameter
indga
indicator of ga parameters
glob
indicator of global parametrization for the covariates
refitem
vector of reference items
miss
indicator of presence of missing responses
ltype
type of logit
XXdis
array of covariates for the latent variable
Xlabel
indicator for covariate configuration
ZZ0
design matrix
fort
to use Fortran

Value

lk
log-likelihood function
sc
score vector