Usage
lk_obs_score_between(par_comp, lde, lpar, lga, S, R, yv, k, rm, lv, J, fv, link, disc, indga, glob, refitem, miss, ltype, XXdis, Xlabel, ZZ0,fort)
Arguments
par_comp
complete vector of parameters
R
matrix of observed responses indicator
k
number of latent classes for the latent variable
rm
number of dimensions for the latent variable
lv
number of response categories for each item
fv
indicator of constrained parameters
disc
presence of discrimination parameter
indga
indicator of ga parameters
glob
indicator of global parametrization for the covariates
refitem
vector of reference items
miss
indicator of presence of missing responses
XXdis
array of covariates for the latent variable
Xlabel
indicator for covariate configuration